package org.dromara.zhishu.mapper;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.dromara.common.mybatis.core.mapper.BaseMapperPlus;
import org.dromara.zhishu.domain.TLogistics;
import org.dromara.zhishu.domain.bo.TLogisticsBo;
import org.dromara.zhishu.domain.vo.TDepotVo;
import org.dromara.zhishu.domain.vo.TLogisticsVo;
import org.springframework.data.repository.query.Param;

import java.util.Collection;
import java.util.List;

/**
 * 物流管理Mapper接口
 *
 * @author Lion Li
 * @date 2025-04-22
 */
@Mapper
public interface TLogisticsMapper extends BaseMapperPlus<TLogistics, TLogisticsVo> {

    TDepotVo selectDepotName(Long depotId);

    Page<TLogisticsVo> selectPageVo(@Param("page") Page<Object> build, @Param("bo") TLogisticsBo bo);

    TLogisticsVo selectByLId(Long id);

    List<TLogisticsVo> nameList(List<Long> depotIds);

    String selectByArea(String deliveryArea, String deliveryCity);

    String selectByCity(String deliveryCity, String deliveryProvince);

    String selectByProvince(String deliveryProvince);

    int deleteIds(Collection<Long> ids);

    List<Long> selectDepotId(Long userId);


    List<TLogisticsVo> selectUserId(Long userId);
}
